Nothing class final

A class representing the absence of a value.

This is useful when you need to return a value from a function that doesn't have a meaningful result.

Constructors

Nothing()
A class representing the absence of a value.
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited