short library

Classes

Absent<T>
Represents an absent value.
Failure<S, F>
Represents a failed result.
Mallard
The class that handles global Mallard configurations.
Maybe<T>
Represents a value that may be present or absent.
Nothing
A class representing the absence of a value.
Present<T>
Represents a present value.
Success<S, F>
Represents a successful result.

Extension Types

Res
Represents a result that can either be successful or fail.
Task
Represents asynchronous tasks that can succeed or fail.

Constants

nothing → const Nothing
A class representing the absence of a value.

Functions

absent<T>() Maybe<T>
Creates an instance of Absent.
maybe<T>(T? value) Maybe<T>
Creates a Maybe from a nullable value.
present<T>(T value) Maybe<T>
Creates an instance of Present containing the provided value.