run method

FutureOr<Res<S, F>> run()

Executes the task and returns a Future that completes with a Result containing either a success value of type S or a failure value of type F.

This method also triggers the Mallard.onTaskSuccess and Mallard.onTaskFailure callbacks based on the outcome of the task.

Implementation

FutureOr<Res<S, F>> run() => _task.run() as FutureOr<Res<S, F>>;